**Pyntfa**
======

## Description

**Pyntfa* is a python package for non-stationary time-frequency analysis. 
This package has a variety of applications in both exploration and earthquake seismology.

## Reference

Chen, Y., 2021, Nonstationary local time-frequency transform, Geophysics, 86(3), V245–V254.

BibTeX:

	@article{ntfa,
	  title={Nonstationary local time-frequency transform},
	  author={Yangkang Chen},
	  journal={Geophysics},
	  volume={86},
	  number={3},
	  issue={3},
	  pages={V245–V254},
	  doi={10.1190/geo2020-0298.1},
	  year={2021}
	}

-----------
## Copyright
    The pyntfa developing team, 2021-present
-----------

## License
    GNU General Public License, Version 3
    (http://www.gnu.org/copyleft/gpl.html)   

-----------

## Install
Using the latest version

    git clone https://github.com/chenyk1990/pyntfa
    cd pyntfa
    pip install -v -e .
or using Pypi

    pip install pyntfa

-----------
## Examples
    The "demo" directory contains all runable scripts to demonstrate different applications of pyntfa. 

-----------
## Gallery
The gallery figures of the pyntfapackage can be found at
    https://github.com/chenyk1990/gallery/tree/main/pyntfa
Each figure in the gallery directory corresponds to a DEMO script in the "demo" directory with the exactly the same file name.

-----------
## Dependence Packages
* scipy 
* numpy 
* matplotlib

-----------
## Modules
    xxx.py  -> description
    
-----------
## Development
    The development team welcomes voluntary contributions from any open-source enthusiast. 
    If you want to make contribution to this project, feel free to contact the development team. 

-----------
## Contact
    Regarding any questions, bugs, developments, collaborations, please contact  
    Yangkang Chen
    chenyk2016@gmail.com

-----------
## Examples

Under construction

<!-- <img src='./test.png' alt='Adj' width=960/> -->

